==> qtjambi-webenginecore-6.5.6-sources.jar: io/qt/webengine/core/QWebEngineCertificateError.java <==
package io.qt.webengine.core;

import io.qt.*;


/**
 * <p>Information about a certificate error</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html">QWebEngineCertificateError</a></code></p>
 */
public class QWebEngineCertificateError extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineCertificateError.class);
    
    /**
     * <p>Java wrapper for Qt enum <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::Type</a></code></p>
     */
    public enum Type implements QtEnumerator {
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>SslPinnedKeyNotInCertificateChain</a></code></p>
         */
        SslPinnedKeyNotInCertificateChain(-150),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateCommonNameInvalid</a></code></p>
         */
        CertificateCommonNameInvalid(-200),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateDateInvalid</a></code></p>
         */
        CertificateDateInvalid(-201),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateAuthorityInvalid</a></code></p>
         */
        CertificateAuthorityInvalid(-202),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateContainsErrors</a></code></p>
         */
        CertificateContainsErrors(-203),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateNoRevocationMechanism</a></code></p>
         */
        CertificateNoRevocationMechanism(-204),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateUnableToCheckRevocation</a></code></p>
         */
        CertificateUnableToCheckRevocation(-205),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateRevoked</a></code></p>
         */
        CertificateRevoked(-206),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateInvalid</a></code></p>
         */
        CertificateInvalid(-207),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateWeakSignatureAlgorithm</a></code></p>
         */
        CertificateWeakSignatureAlgorithm(-208),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateNonUniqueName</a></code></p>
         */
        CertificateNonUniqueName(-210),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateWeakKey</a></code></p>
         */
        CertificateWeakKey(-211),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateNameConstraintViolation</a></code></p>
         */
        CertificateNameConstraintViolation(-212),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateValidityTooLong</a></code></p>
         */
        CertificateValidityTooLong(-213),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateTransparencyRequired</a></code></p>
         */
        CertificateTransparencyRequired(-214),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateSymantecLegacy</a></code></p>
         */
        CertificateSymantecLegacy(-215),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateKnownInterceptionBlocked</a></code></p>
         */
        CertificateKnownInterceptionBlocked(-217),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>SslObsoleteVersion</a></code></p>
         */
        SslObsoleteVersion(-218);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private Type(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static @NonNull Type resolve(int value) {
            switch (value) {
            case -150: return SslPinnedKeyNotInCertificateChain;
            case -200: return CertificateCommonNameInvalid;
            case -201: return CertificateDateInvalid;
            case -202: return CertificateAuthorityInvalid;
            case -203: return CertificateContainsErrors;
            case -204: return CertificateNoRevocationMechanism;
            case -205: return CertificateUnableToCheckRevocation;
            case -206: return CertificateRevoked;
            case -207: return CertificateInvalid;
            case -208: return CertificateWeakSignatureAlgorithm;
            case -210: return CertificateNonUniqueName;
            case -211: return CertificateWeakKey;
            case -212: return CertificateNameConstraintViolation;
            case -213: return CertificateValidityTooLong;
            case -214: return CertificateTransparencyRequired;
            case -215: return CertificateSymantecLegacy;
            case -217: return CertificateKnownInterceptionBlocked;
            case -218: return SslObsoleteVersion;
            default: throw new QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    /**
     * <p>See <code>QWebEngineCertificateError::<wbr/>QWebEngineCertificateError(QWebEngineCertificateError)</code></p>
     */
    public QWebEngineCertificateError(io.qt.webengine.core.@NonNull QWebEngineCertificateError other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QWebEngineCertificateError instance, io.qt.webengine.core.QWebEngineCertificateError other);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#acceptCertificate">QWebEngineCertificateError::<wbr/>acceptCertificate()</a></code></p>
     */
    public final void acceptCertificate(){
        acceptCertificate_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void acceptCertificate_native(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#certificateChain">QWebEngineCertificateError::<wbr/>certificateChain()const</a></code></p>
     */
    @SuppressWarnings({"exports"})
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.network.@NonNull QSslCertificate> certificateChain(){
        return certificateChain_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.network.QSslCertificate> certificateChain_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#defer">QWebEngineCertificateError::<wbr/>defer()</a></code></p>
     */
    public final void defer(){
        defer_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void defer_native(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#description">QWebEngineCertificateError::<wbr/>description()const</a></code></p>
     */
    @QtPropertyReader(name="description")
    @QtPropertyConstant
    @QtUninvokable
    public final java.lang.@NonNull String description(){
        return description_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String description_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#overridable-prop">QWebEngineCertificateError::<wbr/>isOverridable()const</a></code></p>
     */
    @QtPropertyReader(name="overridable")
    @QtPropertyConstant
    @QtUninvokable
    public final boolean isOverridable(){
        return isOverridable_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isOverridable_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineCertificateError::<wbr/>operator=(QWebEngineCertificateError)</code></p>
     */
    @QtUninvokable
    public final void assign(io.qt.webengine.core.@NonNull QWebEngineCertificateError other){
        assign_native_cref_QWebEngineCertificateError(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QWebEngineCertificateError(long __this__nativeId, long other);
    
    /**
     * <p>See <code>operator==(QWebEngineCertificateError,<wbr/>QWebEngineCertificateError)</code></p>
     */
    @QtUninvokable
    public final boolean equals(io.qt.webengine.core.@NonNull QWebEngineCertificateError arg2){
        return equals_native_cref_QWebEngineCertificateError(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg2));
    }
    
    @QtUninvokable
    private native boolean equals_native_cref_QWebEngineCertificateError(long __this__nativeId, long arg2);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#rejectCertificate">QWebEngineCertificateError::<wbr/>rejectCertificate()</a></code></p>
     */
    public final void rejectCertificate(){
        rejectCertificate_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void rejectCertificate_native(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#type">QWebEngineCertificateError::<wbr/>type()const</a></code></p>
     */
    @QtPropertyReader(name="type")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.webengine.core.QWebEngineCertificateError.@NonNull Type type(){
        return io.qt.webengine.core.QWebEngineCertificateError.Type.resolve(type_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int type_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#url">QWebEngineCertificateError::<wbr/>url()const</a></code></p>
     */
    @QtPropertyReader(name="url")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl url(){
        return url_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl url_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QWebEngineCertificateError(QPrivateConstructor p) { super(p); } 
    

    /**
     * <p>See <code>operator==(QWebEngineCertificateError,<wbr/>QWebEngineCertificateError)</code></p>
     */
    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.webengine.core.QWebEngineCertificateError) {
            return equals((io.qt.webengine.core.QWebEngineCertificateError) other);
        }

        return false;
    }


    /**
     * Returns the objects's hash code computed by <code>qHash(QWebEngineCertificateError)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
    <p>See <code>QWebEngineCertificateError::<wbr/>QWebEngineCertificateError(QWebEngineCertificateError)</code></p>
     */
    @QtUninvokable
    @Override
    public QWebEngineCertificateError clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QWebEngineCertificateError clone_native(long __this_nativeId);
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #description()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final java.lang.@NonNull String getDescription() {
        return description();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #isOverridable()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final boolean getOverridable() {
        return isOverridable();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #type()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.webengine.core.QWebEngineCertificateError.@NonNull Type getType() {
        return type();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #url()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl getUrl() {
        return url();
    }
}

==> qtjambi-webenginecore-6.5.7-sources.jar: io/qt/webengine/core/QWebEngineCertificateError.java <==
package io.qt.webengine.core;

import io.qt.*;


/**
 * <p>Information about a certificate error</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html">QWebEngineCertificateError</a></code></p>
 */
public class QWebEngineCertificateError extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineCertificateError.class);
    
    /**
     * <p>Java wrapper for Qt enum <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::Type</a></code></p>
     */
    public enum Type implements QtEnumerator {
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>SslPinnedKeyNotInCertificateChain</a></code></p>
         */
        SslPinnedKeyNotInCertificateChain(-150),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateCommonNameInvalid</a></code></p>
         */
        CertificateCommonNameInvalid(-200),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateDateInvalid</a></code></p>
         */
        CertificateDateInvalid(-201),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateAuthorityInvalid</a></code></p>
         */
        CertificateAuthorityInvalid(-202),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateContainsErrors</a></code></p>
         */
        CertificateContainsErrors(-203),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateNoRevocationMechanism</a></code></p>
         */
        CertificateNoRevocationMechanism(-204),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateUnableToCheckRevocation</a></code></p>
         */
        CertificateUnableToCheckRevocation(-205),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateRevoked</a></code></p>
         */
        CertificateRevoked(-206),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateInvalid</a></code></p>
         */
        CertificateInvalid(-207),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateWeakSignatureAlgorithm</a></code></p>
         */
        CertificateWeakSignatureAlgorithm(-208),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateNonUniqueName</a></code></p>
         */
        CertificateNonUniqueName(-210),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateWeakKey</a></code></p>
         */
        CertificateWeakKey(-211),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateNameConstraintViolation</a></code></p>
         */
        CertificateNameConstraintViolation(-212),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateValidityTooLong</a></code></p>
         */
        CertificateValidityTooLong(-213),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateTransparencyRequired</a></code></p>
         */
        CertificateTransparencyRequired(-214),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateSymantecLegacy</a></code></p>
         */
        CertificateSymantecLegacy(-215),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>CertificateKnownInterceptionBlocked</a></code></p>
         */
        CertificateKnownInterceptionBlocked(-217),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#Type-enum">QWebEngineCertificateError::<wbr/>SslObsoleteVersion</a></code></p>
         */
        SslObsoleteVersion(-218);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private Type(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        @Override
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static @NonNull Type resolve(int value) {
            switch (value) {
            case -150: return SslPinnedKeyNotInCertificateChain;
            case -200: return CertificateCommonNameInvalid;
            case -201: return CertificateDateInvalid;
            case -202: return CertificateAuthorityInvalid;
            case -203: return CertificateContainsErrors;
            case -204: return CertificateNoRevocationMechanism;
            case -205: return CertificateUnableToCheckRevocation;
            case -206: return CertificateRevoked;
            case -207: return CertificateInvalid;
            case -208: return CertificateWeakSignatureAlgorithm;
            case -210: return CertificateNonUniqueName;
            case -211: return CertificateWeakKey;
            case -212: return CertificateNameConstraintViolation;
            case -213: return CertificateValidityTooLong;
            case -214: return CertificateTransparencyRequired;
            case -215: return CertificateSymantecLegacy;
            case -217: return CertificateKnownInterceptionBlocked;
            case -218: return SslObsoleteVersion;
            default: throw new QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    /**
     * <p>See <code>QWebEngineCertificateError::<wbr/>QWebEngineCertificateError(QWebEngineCertificateError)</code></p>
     */
    public QWebEngineCertificateError(io.qt.webengine.core.@NonNull QWebEngineCertificateError other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QWebEngineCertificateError instance, io.qt.webengine.core.QWebEngineCertificateError other);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#acceptCertificate">QWebEngineCertificateError::<wbr/>acceptCertificate()</a></code></p>
     */
    public final void acceptCertificate(){
        acceptCertificate_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void acceptCertificate_native(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#certificateChain">QWebEngineCertificateError::<wbr/>certificateChain()const</a></code></p>
     */
    @SuppressWarnings({"exports"})
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.network.@NonNull QSslCertificate> certificateChain(){
        return certificateChain_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.network.QSslCertificate> certificateChain_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#defer">QWebEngineCertificateError::<wbr/>defer()</a></code></p>
     */
    public final void defer(){
        defer_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void defer_native(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#description">QWebEngineCertificateError::<wbr/>description()const</a></code></p>
     */
    @QtPropertyReader(name="description")
    @QtPropertyConstant
    @QtUninvokable
    public final java.lang.@NonNull String description(){
        return description_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String description_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#overridable-prop">QWebEngineCertificateError::<wbr/>isOverridable()const</a></code></p>
     */
    @QtPropertyReader(name="overridable")
    @QtPropertyConstant
    @QtUninvokable
    public final boolean isOverridable(){
        return isOverridable_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isOverridable_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineCertificateError::<wbr/>operator=(QWebEngineCertificateError)</code></p>
     */
    @QtUninvokable
    public final void assign(io.qt.webengine.core.@NonNull QWebEngineCertificateError other){
        assign_native_cref_QWebEngineCertificateError(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QWebEngineCertificateError(long __this__nativeId, long other);
    
    /**
     * <p>See <code>operator==(QWebEngineCertificateError,<wbr/>QWebEngineCertificateError)</code></p>
     */
    @QtUninvokable
    public final boolean equals(io.qt.webengine.core.@NonNull QWebEngineCertificateError arg2){
        return equals_native_cref_QWebEngineCertificateError(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg2));
    }
    
    @QtUninvokable
    private native boolean equals_native_cref_QWebEngineCertificateError(long __this__nativeId, long arg2);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#rejectCertificate">QWebEngineCertificateError::<wbr/>rejectCertificate()</a></code></p>
     */
    public final void rejectCertificate(){
        rejectCertificate_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void rejectCertificate_native(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#type">QWebEngineCertificateError::<wbr/>type()const</a></code></p>
     */
    @QtPropertyReader(name="type")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.webengine.core.QWebEngineCertificateError.@NonNull Type type(){
        return io.qt.webengine.core.QWebEngineCertificateError.Type.resolve(type_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int type_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginecertificateerror.html#url">QWebEngineCertificateError::<wbr/>url()const</a></code></p>
     */
    @QtPropertyReader(name="url")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl url(){
        return url_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl url_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QWebEngineCertificateError(QPrivateConstructor p) { super(p); } 
    

    /**
     * <p>See <code>operator==(QWebEngineCertificateError,<wbr/>QWebEngineCertificateError)</code></p>
     */
    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other==null || other instanceof io.qt.webengine.core.QWebEngineCertificateError) {
            return equals((io.qt.webengine.core.QWebEngineCertificateError) other);
        }

        return false;
    }


    /**
     * Returns the objects's hash code computed by <code>qHash(QWebEngineCertificateError)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
    <p>See <code>QWebEngineCertificateError::<wbr/>QWebEngineCertificateError(QWebEngineCertificateError)</code></p>
     */
    @QtUninvokable
    @Override
    public QWebEngineCertificateError clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QWebEngineCertificateError clone_native(long __this_nativeId);
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #description()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final java.lang.@NonNull String getDescription() {
        return description();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #isOverridable()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final boolean getOverridable() {
        return isOverridable();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #type()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.webengine.core.QWebEngineCertificateError.@NonNull Type getType() {
        return type();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #url()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl getUrl() {
        return url();
    }
}
